import { LLMProvider } from '../../constants/llmProvider';
import { ILocalTool } from '../../types';
import { AgentStatus, IAgentTool, ISourceNode, SourceNodeType, IAgentInstructions, AgentAccessScope, IAgentGraphItem } from '../../types/agents';
import { IUserDetails, MemoryStrategy, MemoryType } from '../../types/memory';
import { Base } from '../base';
import { Configuration } from '../Configuration';
import { Execution } from '../executions/Execution';
import { KnowledgeBase } from '../knowledgeBases';
import { Memory } from '../memory';
import { ToolCall, ToolCallResult } from '../toolCalls';
/**
 * Represents an agent in xpanderAI, managing tools, sessions, and operational workflows.
 * This class facilitates loading agents, handling tool executions, and managing prompt groups.
 */
export declare class Agent extends Base {
    configuration: Configuration;
    id: string;
    name: string;
    organizationId: string;
    status: AgentStatus;
    memoryType: MemoryType;
    memoryStrategy: MemoryStrategy;
    instructions: IAgentInstructions;
    accessScope: AgentAccessScope;
    sourceNodes: ISourceNode[];
    prompts: string[];
    tools: IAgentTool[];
    graph: IAgentGraphItem[];
    knowledgeBases: KnowledgeBase[];
    /** Indicates if the agent is ready and tools are loaded. */
    ready: boolean;
    /** Collection of local tools specific to this agent. */
    localTools: ILocalTool[];
    execution?: Execution;
    userDetails?: IUserDetails;
    executionMemory?: Memory;
    private shouldStop;
    private isLocalRun;
    /** Maps original tool names to renamed versions for consistency. */
    protected originalToolNamesReMapping: Record<string, string>;
    /**
     * Constructs a new Agent instance.
     *
     * @param configuration - Configuration settings for the agent.
     * @param id - Unique identifier for the agent.
     * @param name - Human-readable name of the agent.
     * @param organizationId - Organization ID to which the agent belongs.
     * @param status - Current status of the agent.
     * @param memoryType - Type of memory the agent utilizes.
     * @param memoryStrategy - Strategy for memory management.
     * @param instructions - Instructions for the agent's operation.
     * @param accessScope - Scope of the agent's access permissions.
     * @param sourceNodes - Source nodes associated with the agent.
     * @param prompts - Prompts used by the agent.
     * @param tools - Tools available to the agent.
     * @param graph - Graph structure representing the agent's operational flow.
     * @param knowledgeBases - Knowledge bases associated with the agent.
     */
    constructor(configuration: Configuration, id: string, name: string, organizationId: string, status: AgentStatus, memoryType: MemoryType, memoryStrategy: MemoryStrategy, instructions: IAgentInstructions, accessScope: AgentAccessScope, sourceNodes: ISourceNode[], prompts: string[], tools?: IAgentTool[], graph?: IAgentGraphItem[], knowledgeBases?: KnowledgeBase[]);
    /** Loads the agent data from its source node type. */
    load(agentId?: string): void;
    /**
     * Retrieves tools compatible with a specified LLM provider.
     *
     * @param llmProvider - The LLM provider to filter tools by (default: `OPEN_AI`).
     * @returns A list of tools matching the specified provider.
     */
    getTools(llmProvider?: LLMProvider): any[];
    /** Constructs the API URL for this agent. */
    get url(): string;
    /**
     * Adds local tools to the agent with prefixed function names.
     *
     * @param tools - The list of local tools to add.
     */
    addLocalTools(tools: any[] | ILocalTool[]): void;
    /** Checks if the agent has local tools loaded. */
    get hasLocalTools(): boolean;
    /**
     * Executes a single tool call and returns the result.
     *
     * @param tool - The tool call to execute.
     * @param payloadExtension - Additional payload data to merge.
     * @returns The result of the tool execution.
     */
    runTool(tool: ToolCall, payloadExtension?: any, isMultiple?: boolean): ToolCallResult;
    /**
     * Executes multiple tool calls sequentially and returns their results.
     *
     * @param toolCalls - The list of tool calls to execute.
     * @param payloadExtension - Additional payload data to merge.
     * @returns A list of results for each tool execution.
     */
    runTools(toolCalls: ToolCall[], payloadExtension?: any): ToolCallResult[];
    /** Retrieves the type of source node for the agent. */
    get sourceNodeType(): SourceNodeType;
    /**
     * Retrieves a node from the graph by its ID.
     *
     * @param itemId - The ID of the graph node to retrieve.
     * @returns The matching graph node, or undefined if not found.
     */
    retrieveNodeFromGraph(itemId: string): IAgentGraphItem | undefined;
    /**
     * Initializes the task execution for the agent.
     *
     * @param execution - The execution details.
     */
    initTask(execution: any): void;
    /**
     * Updates the user details for the agent.
     *
     * @param userDetails - The user details to update.
     */
    updateUserDetails(userDetails: any): void;
    /** Retrieves the vanilla knowledge bases of the agent. */
    get vanillaKnowledgeBases(): KnowledgeBase[];
    /** Retrieves the memory instance for the agent. */
    get memory(): Memory;
    /** Initializes the memory instance for the agent. */
    private initializeMemory;
    isFinished(): boolean;
    invokeAgent(input?: string, files?: string[], useWorker?: boolean): Execution;
    stop(): void;
    retrieveExecutionResult(): Execution;
}
