import { Agent, IAgentInstructions, LLMProvider, ToolCallResult } from '../..';
import { IMemoryMessage, IUserDetails, MemoryType } from '../../types/memory';
import { Base } from '../base';
/**
 * Represents a memory thread in xpanderAI, handling storage, retrieval,
 * and processing of memory messages and related operations.
 */
export declare class Memory extends Base {
    private agent;
    id: string;
    messages: IMemoryMessage[];
    userDetails: string;
    memoryType: MemoryType;
    /**
     * Creates a new memory thread for the specified agent.
     *
     * @param agent - The agent for which the memory thread is created.
     * @param userDetails - Optional user details associated with the memory thread.
     * @returns A new instance of the Memory class.
     */
    static create(agent: Agent, userDetails?: IUserDetails): Memory;
    /**
     * Fetches an existing memory thread by its ID.
     *
     * @param agent - The agent associated with the memory thread.
     * @param threadId - The ID of the memory thread to fetch.
     * @returns An instance of the Memory class representing the fetched thread.
     */
    static fetch(agent: Agent, threadId: string): Memory;
    /** The LLM provider to be used for message processing. */
    llmProvider: LLMProvider;
    constructor(agent: Agent, id: string, messages: IMemoryMessage[], userDetails: string, memoryType: MemoryType);
    /** Executes the memory strategy and updates the messages accordingly. */
    private runStrategy;
    /**
     * Retrieves the messages stored in the memory thread.
     * Applies the agent's memory strategy to refresh the messages if needed.
     *
     * @returns An array of messages formatted for the selected LLM provider.
     */
    retrieveMessages(): any[];
    /**
     * Adds tool call results as messages to the memory thread.
     *
     * @param toolCallResults - An array of tool call results to be added as messages.
     */
    addToolCallResults(toolCallResults: ToolCallResult[]): void;
    /**
     * Adds messages to the memory thread.
     * Converts non-standard messages to a compatible format before storing.
     *
     * @param _messages - An array of messages to be added to the memory thread.
     */
    addMessages(_messages: any): void;
    /**
     * Initializes the memory thread with system instructions if no messages exist.
     *
     * @param instructions - Instructions to initialize the memory thread.
     */
    initInstructions(instructions: IAgentInstructions): void;
    /**
     * Initializes a new memory thread with input and instructions.
     *
     * @param input - Initial user input message.
     * @param instructions - Instructions to initialize the memory thread.
     */
    initializeThread(input: IMemoryMessage, instructions: IAgentInstructions): void;
    addKnowledgeBase(): void;
    /**
     * Sets the LLM provider for processing memory messages.
     *
     * @param llmProvider - The LLM provider to use.
     */
    selectLLMProvider(llmProvider: LLMProvider): void;
    /**
     * Converts an LLM response to the memory message format.
     *
     * @param response - The LLM response to convert.
     * @returns An array of memory messages formatted for the memory thread.
     */
    private convertLLMResponseToMessages;
}
